/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
#include"TImagesFactory.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component ("Central Component"),
                                         pMessagesLabel(0)
{
    pMessagesLabel = new Label(L"Messages Label", tr("Выберите пункт главного меню \nили щёлкните правой кнопкой мыши за пределами надписи для того, чтобы вызвать контекстное меню."));
    pMessagesLabel->setFont(Font(15.0000f, Font::plain));
    pMessagesLabel->setJustificationType(Justification::centred);
    pMessagesLabel->setEditable (false, false, false);
    pMessagesLabel->setColour(Label::outlineColourId, Colours::black);
    pMessagesLabel->setColour(Label::textColourId, Colours::black);
    pMessagesLabel->setColour(Label::backgroundColourId, Colours::azure);
    addAndMakeVisible(pMessagesLabel);

    ImageExit_png = ImageCache::getFromMemory(TImagesFactory::psExit_png, TImagesFactory::iExit_pngSize);
    ImageNew_png = ImageCache::getFromMemory(TImagesFactory::psNew_png, TImagesFactory::iNew_pngSize);
    ImageOpen_png = ImageCache::getFromMemory(TImagesFactory::psOpen_png, TImagesFactory::iOpen_pngSize);

    setSize (700, 400);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pMessagesLabel->setBounds(0, proportionOfHeight(0.5000f) - 25, proportionOfWidth(1.0000f), 50);
}
//---------------------------------------------------------------------
void TCentralComponent::mouseDown(const MouseEvent& Event)
{
    // Если пользователь пытается вызвать контекстное меню...
    if(Event.mods.isPopupMenu())
    {
        // создаём его...
        PopupMenu LabelPopupMenu;
        // и добавляем в него пункты
        LabelPopupMenu.addItem(FileNew, tr("Новый"), true, false, ImageNew_png);
        LabelPopupMenu.addItem(FileOpen, tr("Открыть"), true, false, ImageOpen_png);
        LabelPopupMenu.addSeparator();
        LabelPopupMenu.addItem(FileQuit, tr("Выход"), true, false, ImageExit_png);

        // Показываем контекстное меню.
        const int iResult = LabelPopupMenu.show();

        // В зависимости от идентификатора команды
        // вызываем тот или иной обработчик.
        if(iResult == FileNew)
        {
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, tr("Информация"), tr("Выбран пункт \"Новый\""), tr("Да"), 0);
        }
        else if(iResult == FileOpen)
        {
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, tr("Информация"), tr("Выбран пункт \"Открыть\""), tr("Да"), 0);
        }
        else if(iResult == FileQuit)
        {
            JUCEApplication::quit();
        }
    }
}
//---------------------------------------------------------------------
const StringArray TCentralComponent::getMenuBarNames()
{
    // Создаются основные пункты меню
    StringArray sMenuNames;
    sMenuNames.add(tr("Файл"));
    return sMenuNames;
}
//---------------------------------------------------------------------
void TCentralComponent::menuItemSelected(int iMenuItemID, int iTopLevelMenuIndex)
{
    // Обработчики команд меню
    switch(iMenuItemID)
    {
    // Если выбран пункт "Выход"...
        case FileQuit:
        {
            // Завершаем работу программы
            JUCEApplication::quit();
            break;
        }
        // Если выбран пункт "Новый"...
        case FileNew:
        {
            // показываем сообщение
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, tr("Информация"), tr("Выбран пункт \"Новый\""), tr("Да"), 0);
            break;
        }
        // Если выбран пункт "Открыть"...
        case FileOpen:
        {
            // показываем сообщение
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, tr("Информация"), tr("Выбран пункт \"Открыть\""), tr("Да"), 0);
            break;
        }
    }
}
//---------------------------------------------------------------------
const PopupMenu TCentralComponent::getMenuForIndex(int iIndex, const String& sMenuName)
{
    // Создаём выпадающее меню
    PopupMenu Menu;

    switch(iIndex)
    {
        // Индекс 0 соответствует пункту меню "Файл"
        // (см. getMenuBarNames)
        case 0:
        {
            // Добавляем новые пункты в меню "Файл"
            Menu.addItem(FileNew, tr("Новый"), true, false, ImageNew_png);
            Menu.addItem(FileOpen, tr("Открыть"), true, false, ImageOpen_png);
            // Добавляем разделитель
            Menu.addSeparator();
            Menu.addItem(FileQuit, tr("Выход"), true, false, ImageExit_png);
            break;
        }
    }

    return Menu;
}
//---------------------------------------------------------------------
