/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
#include"TImagesFactory.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent(TMainForm* pParent) : Component("Central Component"),
                                         pMessagesLabel(0)
{
    this->pParent = pParent;
    
    pMessagesLabel = new Label(L"Messages Label", "");
    pMessagesLabel->setFont(Font(15.0000f, Font::plain));
    pMessagesLabel->setJustificationType(Justification::centred);
    pMessagesLabel->setEditable (false, false, false);
    pMessagesLabel->setColour(Label::outlineColourId, Colours::black);
    pMessagesLabel->setColour(Label::textColourId, Colours::black);
    pMessagesLabel->setColour(Label::backgroundColourId, Colours::azure);
    addAndMakeVisible(pMessagesLabel);

    ImageExit_png = ImageCache::getFromMemory(TImagesFactory::psExit_png, TImagesFactory::iExit_pngSize);
    ImageNew_png = ImageCache::getFromMemory(TImagesFactory::psNew_png, TImagesFactory::iNew_pngSize);
    ImageOpen_png = ImageCache::getFromMemory(TImagesFactory::psOpen_png, TImagesFactory::iOpen_pngSize);

    setSize (700, 400);
    
    bEnglish = true;
    bRussian = false;
    
    LanguageChange();
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::LanguageChange()
{
    if(bEnglish)
    {
        sMessagesLabelText = tr("Choose an option of the main menu \nor right-click outside of the label to invoke a context menu.");
        sFileMenuText = tr("File");
        sLanguageMenuText = tr("Language");
        sFileNewMenuText = tr("New");
        sFileOpenMenuText = tr("Open");
        sFileQuitText = tr("Quit");
        sMessageTitleText = tr("Information");
        sMessageNewText = tr("Option \"New\" was selected");
        sMessageOpenText = tr("Option \"Open\" was selected");
        sYesButtonText = tr("Yes");
    }
    else if(bRussian)
    {
        sMessagesLabelText = tr("Выберите пункт главного меню \nили щёлкните правой кнопкой мыши за пределами надписи для того, чтобы вызвать контекстное меню.");
        sFileMenuText = tr("Файл");
        sLanguageMenuText = tr("Язык");
        sFileNewMenuText = tr("Новый");
        sFileOpenMenuText = tr("Открыть");
        sFileQuitText = tr("Выход");
        sMessageTitleText = tr("Информация");
        sMessageNewText = tr("Выбран пункт \"Новый\"");
        sMessageOpenText = tr("Выбран пункт \"Открыть\"");
        sYesButtonText = tr("Да");
    }
    
    pMessagesLabel->setText(sMessagesLabelText, false);
    getMenuBarNames();
    // Перерисовываем пункты меню с учётом нового языка
    menuItemsChanged();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pMessagesLabel->setBounds(0, proportionOfHeight(0.5000f) - 25, proportionOfWidth(1.0000f), 50);
}
//---------------------------------------------------------------------
void TCentralComponent::mouseDown(const MouseEvent& Event)
{
    if(Event.mods.isPopupMenu())
    {
        PopupMenu LabelPopupMenu;
        LabelPopupMenu.addItem(FileNew, sFileNewMenuText, true, false, ImageNew_png);
        LabelPopupMenu.addItem(FileOpen, sFileOpenMenuText, true, false, ImageOpen_png);
        LabelPopupMenu.addSeparator();
        LabelPopupMenu.addItem(FileQuit, sFileQuitText, true, false, ImageExit_png);

        const int iResult = LabelPopupMenu.show();

        if(iResult == FileNew)
        {
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, sMessageTitleText, sMessageNewText, sYesButtonText, 0);
        }
        else if(iResult == FileOpen)
        {
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, sMessageTitleText, sMessageOpenText, sYesButtonText, 0);
        }
        else if(iResult == FileQuit)
        {
            JUCEApplication::quit();
        }
    }
}
//---------------------------------------------------------------------
const StringArray TCentralComponent::getMenuBarNames()
{
    StringArray sMenuNames;
    sMenuNames.add(sFileMenuText);
    sMenuNames.add(sLanguageMenuText);
    return sMenuNames;
}
//---------------------------------------------------------------------
void TCentralComponent::menuItemSelected(int iMenuItemID, int iTopLevelMenuIndex)
{
    switch(iMenuItemID)
    {
        case FileQuit:
        {
            JUCEApplication::quit();
            break;
        }
        case FileNew:
        {
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, sMessageTitleText, sMessageNewText, sYesButtonText, 0);
            break;
        }
        case FileOpen:
        {
            AlertWindow::showMessageBox(AlertWindow::InfoIcon, sMessageTitleText, sMessageOpenText, sYesButtonText, 0);
            break;
        }
    }
}
//---------------------------------------------------------------------
const PopupMenu TCentralComponent::getMenuForIndex(int iIndex, const String& sMenuName)
{
    ApplicationCommandManager* pCommandManager = &(pParent->CommandManager);
    
    PopupMenu Menu;

    switch(iIndex)
    {
        case 0:
        {
            Menu.addItem(FileNew, sFileNewMenuText, true, false, ImageNew_png);
            Menu.addItem(FileOpen, sFileOpenMenuText, true, false, ImageOpen_png);
            Menu.addSeparator();
            Menu.addItem(FileQuit, sFileQuitText, true, false, ImageExit_png);
            break;
        }
        case 1:
        {
            Menu.addCommandItem(pCommandManager, LanguageEnglish, L"English");
            Menu.addCommandItem(pCommandManager, LanguageRussian, tr("Русский"));
            break;
        }
    }

    return Menu;
}
//---------------------------------------------------------------------
ApplicationCommandTarget* TCentralComponent::getNextCommandTarget()
{
    return findFirstTargetParentComponent();
}
//---------------------------------------------------------------------
void TCentralComponent::getAllCommands(Array<int>& iCommands)
{
    // Регистрация команд для командного менеджера
    const CommandID IDs[] =
    {
        LanguageEnglish,
        LanguageRussian
    };
    
    iCommands.addArray(IDs, numElementsInArray(IDs));
}
//---------------------------------------------------------------------
void TCentralComponent::getCommandInfo(CommandID ID, ApplicationCommandInfo& Result)
{
    switch(ID)
    {
        case LanguageEnglish:
        {
            Result.setInfo(L"English", L"Switch to English", "Language", 0);
            Result.setTicked(bEnglish);
            break;
        }
        case LanguageRussian:
        {
            Result.setInfo(tr("Русский"), L"Switch to Russian", "Language", 0);
            Result.setTicked(bRussian);
            break;
        }
    }
}
//---------------------------------------------------------------------
bool TCentralComponent::perform(const InvocationInfo& Info)
{
    switch(Info.commandID)
    {
        case LanguageEnglish:
        {
            // Отмечаем пункт меню - английский
            bEnglish = true;
            bRussian = false;
            break;
        }
        case LanguageRussian:
        {
            // Отмечаем пункт меню - русский
            bEnglish = false;
            bRussian = true;
            break;
        }
    }
    
    // Меняем язык интерфейса
    LanguageChange();

    return true;
}
//---------------------------------------------------------------------
