/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#ifndef _TCentralComponent_h_
#define _TCentralComponent_h_
//---------------------------------------------------------------------
#include "../JuceLibraryCode/JuceHeader.h"
#include "TMainForm.h"
//---------------------------------------------------------------------
// Класс компонента содержимого.
// Наследует класс приёмника команд
class TCentralComponent  : public Component,
                           public MenuBarModel,
                           public ApplicationCommandTarget
{
public:
    TCentralComponent(TMainForm* pParent);
    ~TCentralComponent();

    // Идентификаторы команд меню
    enum TMenuOptions
    {
        FileNew = 1,
        FileOpen = 2,
        FileQuit = 3,
        LanguageEnglish = 4,
        LanguageRussian = 5
    };

    void paint(Graphics&);
    void resized();
    void mouseDown(const MouseEvent&);
    const StringArray getMenuBarNames();
    void menuItemSelected(int, int);
    const PopupMenu getMenuForIndex(int, const String&);
    
    // Функции, наследуемые от ApplicationCommandTarget
    // Возвращает следующий после текущего приёмник команд
    ApplicationCommandTarget* getNextCommandTarget();
    // Возвращает список всех команд, которые могут быть обработаны
    void getAllCommands(Array<int>&);
    // Предоставляет всю необходимую информацию по обрабатываемой команде
    void getCommandInfo(CommandID, ApplicationCommandInfo&);
    // Запускает команду на выполнение
    bool perform(const InvocationInfo&);
    
    // Обработчик смены команд интерфейса
    void LanguageChange();

private:
    // Флаги, какой язык выбран
    bool bEnglish;
    bool bRussian;
    // Родительский компонент
    TMainForm* pParent;
    // Ярлык для вывода сообщений
    Label* pMessagesLabel;
    
    // Строки интерфейса
    String sMessagesLabelText;
    String sFileMenuText;
    String sLanguageMenuText;
    String sFileNewMenuText;
    String sFileOpenMenuText;
    String sFileQuitText;
    String sMessageTitleText;
    String sMessageNewText;
    String sMessageOpenText;
    String sYesButtonText;

    Image ImageNew_png;
    Image ImageOpen_png;
    Image ImageExit_png;

    // Предотвращает создание копии конструктора и оператора =
    TCentralComponent(const TCentralComponent&);
    const TCentralComponent& operator= (const TCentralComponent&);
};
//---------------------------------------------------------------------
#endif
